Additional CircuitPython Libraries and Drivers on GitHub
=========================================================

These are libraries and drivers available in separate GitHub repos. They are
designed for use with CircuitPython and may or may not work with
`MicroPython <https://micropython.org>`_.


Adafruit CircuitPython Library Bundle
--------------------------------------

We provide a bundle of all our libraries to ease installation of drivers and
their dependencies. The bundle is primarily geared to the Adafruit Express line
of boards which feature a relatively large external flash. With Express boards,
it's easy to copy them all onto the filesystem. However, if you don't have
enough space simply copy things over as they are needed.

- The Adafruit bundles are available on GitHub: <https://github.com/adafruit/Adafruit_CircuitPython_Bundle/releases>.

- Documentation for the bundle, which includes links to documentation for all
  libraries, is available here: <https://circuitpython.readthedocs.io/projects/bundle/en/latest/>.


CircuitPython Community Library Bundle
---------------------------------------

This bundle contains non-Adafruit sponsored libraries, that are written and submitted
by members of the community.

- The Community bundles are available on GitHub: <https://github.com/adafruit/CircuitPython_Community_Bundle/releases>.

- Documentation is not available on ReadTheDocs at this time. See each library for any
  included documentation.
